<?php
require_once($_SERVER['DOCUMENT_ROOT'].'/cada/includes/classes/fotolia.class.php');
class fotoliaApiClientCached extends Fotolia_Api
{
    // Cache Time To Live
    const CACHE_TTL = 86400; // 24 hours

    /**
     * Memcache cache instance
     * @var $_cache Memcache
     */
    private static $_cache;

    /**
     * Call the API if there is a cache miss
     * or use the cached data
     *
     * @param  string $method_name
     * @param  string $method_params
     * @return mixed
     */
    public function request($method_name, $method_params)
    {
        $cache = fotoliaApiClientCached::_getCache();

        // compute a cache key based on the call
        $cache_key = sha1($method_name . '-' . implode('-', $method_params));

        // try to get data from memcache
        $data = $cache->get($cache_key);

        if ($data !== FALSE) {
            // cache hit
            $data = json_decode($data, TRUE);
        } else {
            // cache miss

            // call the api
            $data = parent::request($method_name, $method_params);

            // cache result for 24 hours
            $cache->set($cache_key, json_encode($data), 0, fotoliaApiClientCached::CACHE_TTL);
        }

        return $data;
    }

    /**
     * Return a memcache instance
     *
     * @return Memcache
     */
    private static function _getCache()
    {
        if (fotoliaApiClientCached::$_cache === NULL) {
            fotoliaApiClientCached::$_cache = new Memcache();
            $cache->addServer('memcache host', 'memcache port', TRUE);
        }

        return fotoliaApiClientCached::$_cache;
    }
}
?>